..
    Copyright 2021 IRT Saint Exupéry, https://www.irt-saintexupery.com

    This work is licensed under the Creative Commons Attribution-ShareAlike 4.0
    International License. To view a copy of this license, visit
    http://creativecommons.org/licenses/by-sa/4.0/ or send a letter to Creative
    Commons, PO Box 1866, Mountain View, CA 94042, USA.

The developers thank all the open source libraries making GEMSEO-matlab possible.

External Dependencies
---------------------

GEMSEO-matlab depends on software with compatible licenses that are listed below.

`GEMSEO <http://gemseo.org/>`_
    GNU LGPL v3.0

`MATLAB Engine API for Python <https://pypi.org/project/matlabengine>`_
    MathWorks XSLA License

`Python <http://python.org/>`_
    Python Software License

Internal Dependencies
---------------------

GEMSEO-matlab source code includes software with compatible licenses that are listed below.

External application
--------------------

Some external applications are used by GEMSEO-matlab,
but not linked with the application,
for documentation generation,
training or example purposes.

`black <https://black.readthedocs.io>`_
    MIT

`commitizen <https://commitizen-tools.github.io/commitizen/>`_
    MIT

`flake8 <https://flake8.pycqa.org>`_
    MIT

`pre-commit <https://pre-commit.com>`_
    MIT

`pygrep-hooks <https://github.com/pre-commit/pygrep-hooks>`_
    MIT

`pytest <https://pytest.org>`_
    MIT

`pytest-cov <https://pytest-cov.readthedocs.io>`_
    MIT

`pytest-xdist <https://github.com/pytest-dev/pytest-xdist>`_
    MIT

`reorder-python-imports <https://github.com/asottile/reorder_python_imports>`_
    MIT

`setuptools <https://setuptools.readthedocs.io/>`_
    MIT

`setuptools_scm <https://github.com/pypa/setuptools_scm/>`_
    MIT

Resources
---------

Some icons and fonts are used by GEMSEO-matlab or its documentation.
